
	org $8000

	;test code

begin

	ld hl,music_data
	call play
	ret
	
	
	
	;engine code

;squat by Shiru, 06'17
;Squeeker like, just without the output value table
;4 channels of tone with different duty cycle
;sample drums, non-interrupting
;customizeable noise percussion, interrupting


;music data is all 16-bit words, first control then a few optional ones

;control word is PSSSSSSS DDDN4321, where P equ percussion,S equ speed, D equ drum, N equ noise mode, 4321 equ channels
;D triggers non-interruping sample drum
;P trigger
;if 1, channel 1 freq follows
;if 2, channel 2 freq follows
;if 3, channel 3 freq follows
;if 4, channel 4 freq follows
;if N, channel 4 mode follows, it is either $0000 (normal) or $04cb (noise)
;if P, percussion follows, LSB equ volume, MSB equ pitch



RLC_H equ $04cb			;to enable noise mode
NOP_2 equ $0000			;to disable noise mode
RLC_HL equ $06cb		;to enable sample reading
ADD_IX_IX equ $29dd		;to disable sample reading


play

	di
	
	ld e,(hl)
	inc hl
	ld d,(hl)
	inc hl
	ld (loop_ptr),de
	
	ld (pattern_ptr),hl
	
	ld hl,ADD_IX_IX
	ld (sample_read),hl
	ld hl,NOP_2					;normal mode
	ld (noise_mode),hl
	
	ld ix,0						;needs to be 0 to skip sample reading

	ld c,0
	exx
	ld de,$0808					;sample bit counter and reload value

play_loop

pattern_ptr equ $+1
	ld sp,0
	
return_loop

	pop bc						;control word
								;B equ duration of the row (0 equ loop)
								;C equ flags DDDN4321 (Drum, Noise, 1-4 channel update)
	ld a,b
	or a
	jp nz,no_loop
	
loop_ptr equ $+1
	ld sp,0
	
	jp return_loop
	
no_loop

	ld a,c
	
	rra
	jr nc,skip_note_0
	
	pop hl
	ld (ch0_add),hl
	
skip_note_0

	rra
	jr nc,skip_note_1

	pop hl
	ld (ch1_add),hl
	
skip_note_1

	rra
	jr nc,skip_note_2
	
	pop hl
	ld (ch2_add),hl
	
skip_note_2

	rra
	jr nc,skip_note_3
	
	pop hl
	ld (ch3_add),hl
	
skip_note_3

	rra
	jr nc,skip_mode_change
	
	pop hl						;nop:nop or rlc h
	ld (noise_mode),hl

skip_mode_change

	and 7
	jp z,skip_drum
	
	ld hl,sample_list-2
	add a,a
	add a,l
	ld l,a
	ld a,(hl)
	inc l
	ld h,(hl)
	ld l,a
	ld (sample_ptr),hl
	ld hl,RLC_HL
	ld (sample_read),hl

skip_drum

	bit 7,b						;check percussion flag
	jp z,skip_percussion

	res 7,b						;clear percussion flag
	dec b						;compensate speed

	ld (noise_bc),bc
	ld (noise_de),de

	pop hl						;read percussion parameters

	ld a,l						;noise volume
	ld (noise_volume),a
	ld b,h						;noise pitch
	ld c,h
	ld de,$2174					;utz's rand seed			
	exx
	ld bc,811					;noise duration, takes as long as inner sound loop

noise_loop

	exx							;4
	dec c						;4
	jr nz,noise_skip			;7/12
	ld c,b						;4
	add hl,de					;11
	rlc h						;8		utz's noise generator idea
	inc d						;4		improves randomness
	jp noise_next				;10
	
noise_skip

	jr $+2						;12
	jr $+2						;12
	nop							;4
	nop							;4
	
noise_next

	ld a,h						;4
	
noise_volume equ $+1
	cp $80						;7
	sbc a,a						;4
;	out ($fe),a					;11
	and 32
	ld (26624), a

	exx							;4

	dec bc						;6
	ld a,b						;4
	or c						;4
	jp nz,noise_loop			;10 equ 106t

	exx

noise_bc equ $+1
	ld bc,0
noise_de equ $+1
	ld de,0



skip_percussion

	ld (pattern_ptr),sp

sample_ptr equ $+1
	ld hl,0

	ld c,0						;internal loop runs 256 times

sound_loop

sample_read equ $
	rlc (hl)					;15 	rotate sample bits in place, rl (hl) or add ix,ix (dummy operation)
	sbc a,a						;4		sbc a,a to make bit into 0 or 255, or xor a to keep it 0

	dec e						;4--+	count bits
	jp z,sample_cycle			;10 |
	jp sample_next				;10

sample_cycle

	ld e,d						;4	|	reload counter
	inc hl						;6--+	advance pointer --24t

sample_next

	exx							;4		squeeker type unrolled code
	ld b,a						;4		sample mask
	xor a						;4
	
	ld sp,sound_list			;10
		
	pop de						;10		ch0_acc
	pop hl						;10		ch0_add
	add hl,de					;11
	rla							;4
	ld (ch0_acc),hl				;16
						
	pop de						;10		ch1_acc
	pop hl						;10		ch1_add
	add hl,de					;11
	rla							;4
	ld (ch1_acc),hl				;16
	
	pop de						;10		ch2_acc
	pop hl						;10		ch2_add
	add hl,de					;11
	rla							;4
	ld (ch2_acc),hl				;16

	pop de						;10		ch3_acc
	pop hl						;10		ch3_add
	add hl,de					;11
	
noise_mode equ $
	ds 2,0						;8		rlc h for noise effects

	rla							;4
	ld (ch3_acc),hl				;16

	add a,c						;4		no table like in Squeeker, channels summed as is, for uneven 'volume'
	add a,$ff					;7
	sbc a,$ff					;7
	ld c,a						;4
	sbc a,a						;4

	or b						;4		mix sample
	
;	out ($fe),a					;11

	and 32
	ld (26624), a

		
	exx							;4

	dec c						;4
	jp nz,sound_loop			;10 equ 336t


	dec hl						;last byte of a 256 byte sample packet is 0 means it was the last packet
	ld a,(hl)
	inc hl
	or a						;check for 0
	jr nz,sample_no_stop

	ld hl,ADD_IX_IX
	ld (sample_read),hl			;disable sample reading

sample_no_stop

	djnz sound_loop

	ld (sample_ptr),hl
	
	jp play_loop
	
	
	

sample_list

	dw sample_1
	dw sample_2
	dw sample_3
	dw sample_4
	dw sample_5
	dw sample_6
	dw sample_7
	
;variables in the sound_list can't be reordered because of stack-based fetching

sound_list

ch0_add		dw 0
ch0_acc		dw 0
ch1_add		dw 0
ch1_acc		dw 0
ch2_add		dw 0
ch2_acc		dw 0
ch3_add		dw 0
ch3_acc		dw 0


;sample data

	

sample_1
	db 4,4,114,125,1,68,0,0,0,0,248,255,255,255,255,255
	db 1,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255
	db 0,0,0,128,255,255,255,255,127,15,1,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
sample_2
	db 62,1,144,127,240,2,0,0,248,255,3,0,0,162,255,55
	db 0,0,128,252,127,4,0,0,252,63,6,0,0,64,68,122
	db 91,253,59,1,17,0,0,0,138,4,0,192,195,45,0,0
	db 0,4,2,0,0,16,2,0,0,0,0,0,0,32,48,1
	db 0,0,0,0,8,208,136,0,0,0,0,72,0,64,4,0
	db 0,0,0,0,72,87,0,0,0,0,0,0,0,34,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
sample_3
	db 0,7,47,1,0,0,0,2,0,8,0,0,0,0,0,0
	db 0,0,0,0,64,64,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
sample_4
sample_5
sample_6
sample_7


;compiled music data

music_data
	dw .loop
.pattern
	dw $21f,$0,$568,$0,$0,NOP_2
	dw $202,$0
	dw $200
	dw $200
	dw $207,$15a,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $206,$ad0,$66e
	dw $206,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $20f,$15a,$9a2,$ad0,$152
	dw $20f,$0,$0,$0,$0
	dw $208,$152
	dw $208,$0
	dw $206,$568,$9a2
	dw $206,$0,$0
	dw $208,$152
	dw $208,$0
	dw $20f,$15a,$66e,$568,$152
	dw $20f,$0,$0,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $206,$819,$66e
	dw $206,$0,$0
	dw $208,$152
	dw $208,$0
	dw $20e,$66e,$819,$152
	dw $20e,$0,$0,$0
	dw $200
	dw $200
	dw $206,$568,$66e
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$134,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$134
	dw $201,$0
	dw $20e,$ad0,$66e,$12c
	dw $20e,$0,$0,$0
	dw $209,$134,$12c
	dw $209,$0,$0
	dw $20f,$134,$9a2,$ad0,$66e
	dw $20f,$0,$0,$0,$0
	dw $208,$12c
	dw $208,$0
	dw $20e,$568,$9a2,$12c
	dw $20e,$0,$0,$0
	dw $208,$66e
	dw $208,$0
	dw $207,$134,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$134
	dw $201,$0
	dw $20e,$819,$66e,$66e
	dw $20e,$0,$0,$0
	dw $208,$12c
	dw $208,$0
	dw $206,$66e,$819
	dw $206,$0,$0
	dw $200
	dw $200
	dw $206,$568,$66e
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$1cd,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $20e,$ad0,$66e,$1c5
	dw $20e,$0,$0,$0
	dw $209,$1cd,$1c5
	dw $209,$0,$0
	dw $207,$1cd,$9a2,$ad0
	dw $207,$0,$0,$0
	dw $208,$1c5
	dw $208,$0
	dw $20e,$568,$9a2,$1c5
	dw $20e,$0,$0,$0
	dw $200
	dw $200
	dw $207,$1cd,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $20e,$819,$66e,$1c5
	dw $20e,$0,$0,$0
	dw $208,$1c5
	dw $208,$0
	dw $206,$66e,$819
	dw $206,$0,$0
	dw $200
	dw $200
	dw $206,$568,$66e
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$1cd,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $20e,$ad0,$66e,$1c5
	dw $20e,$0,$0,$0
	dw $209,$1cd,$1c5
	dw $209,$0,$0
	dw $207,$1cd,$9a2,$ad0
	dw $207,$0,$0,$0
	dw $208,$1c5
	dw $208,$0
	dw $20a,$568,$ac8
	dw $20a,$0,$0
	dw $20a,$568,$ac0
	dw $20a,$0,$0
	dw $20f,$1cd,$66e,$568,$cd4
	dw $20f,$0,$0,$0,$0
	dw $20f,$1cd,$66e,$568,$ccc
	dw $20f,$0,$0,$0,$0
	dw $20e,$ad0,$66e,$1598
	dw $20e,$0,$0,$0
	dw $20e,$ad0,$66e,$1590
	dw $20e,$0,$0,$0
	dw $20e,$9a2,$ad0,$133c
	dw $20e,$0,$0,$0
	dw $20e,$9a2,$ad0,$1334
	dw $20e,$0,$0,$0
	dw $226,$568,$66e
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$15a,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $22e,$ad0,$66e,$152
	dw $20e,$0,$0,$0
	dw $209,$15a,$152
	dw $209,$0,$0
	dw $207,$15a,$9a2,$ad0
	dw $207,$0,$0,$0
	dw $208,$152
	dw $208,$0
	dw $22e,$568,$9a2,$152
	dw $20e,$0,$0,$0
	dw $200
	dw $200
	dw $207,$15a,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $22e,$819,$66e,$152
	dw $20e,$0,$0,$0
	dw $208,$152
	dw $208,$0
	dw $206,$66e,$819
	dw $206,$0,$0
	dw $200
	dw $200
	dw $226,$568,$66e
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$134,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$134
	dw $201,$0
	dw $22e,$ad0,$66e,$12c
	dw $20e,$0,$0,$0
	dw $209,$134,$12c
	dw $209,$0,$0
	dw $20f,$134,$9a2,$ad0,$66e
	dw $20f,$0,$0,$0,$0
	dw $208,$12c
	dw $208,$0
	dw $22e,$568,$9a2,$12c
	dw $20e,$0,$0,$0
	dw $208,$66e
	dw $208,$0
	dw $207,$134,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$134
	dw $201,$0
	dw $22e,$819,$66e,$66e
	dw $20e,$0,$0,$0
	dw $228,$12c
	dw $208,$0
	dw $226,$66e,$819
	dw $206,$0,$0
	dw $220
	dw $200
	dw $226,$568,$66e
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$1cd,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $22e,$ad0,$66e,$1c5
	dw $20e,$0,$0,$0
	dw $209,$1cd,$1c5
	dw $209,$0,$0
	dw $207,$1cd,$9a2,$ad0
	dw $207,$0,$0,$0
	dw $208,$1c5
	dw $208,$0
	dw $22e,$568,$9a2,$1c5
	dw $20e,$0,$0,$0
	dw $200
	dw $200
	dw $207,$1cd,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $22e,$819,$66e,$1c5
	dw $20e,$0,$0,$0
	dw $208,$1c5
	dw $208,$0
	dw $206,$66e,$819
	dw $206,$0,$0
	dw $200
	dw $200
	dw $226,$568,$66e
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$1cd,$66e,$568
	dw $207,$0,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $22e,$ad0,$66e,$1c5
	dw $20e,$0,$0,$0
	dw $208,$1c5
	dw $208,$0
	dw $20f,$e6,$9a2,$ad0,$d6
	dw $20f,$0,$0,$0,$0
	dw $209,$e6,$d6
	dw $209,$0,$0
	dw $22f,$1cd,$9a2,$568,$1bd
	dw $206,$0,$0
	dw $204,$568
	dw $20d,$0,$0,$0
	dw $20f,$1cd,$568,$66e,$9a2
	dw $20e,$0,$0,$0
	dw $204,$66e
	dw $205,$0,$0
	dw $24f,$1cd,$ad0,$ac0,$568
	dw $20e,$0,$0,$0
	dw $246,$ad0,$ac0
	dw $206,$0,$0
	dw $24e,$ad0,$992,$66e
	dw $24e,$0,$0,$0
	dw $247,$0,$ad0,$992
	dw $246,$0,$0
	dw $227,$15a,$568,$66e
	dw $207,$0,$0,$0
	dw $8205,$15a,$66e,$1110
	dw $204,$0
	dw $26f,$2b4,$66e,$568,$66e
	dw $20e,$0,$0,$0
	dw $8208,$66e,$1110
	dw $208,$0
	dw $247,$15a,$ad0,$66e
	dw $207,$0,$0,$0
	dw $8201,$15a,$f10
	dw $200
	dw $26f,$2b4,$9a2,$ad0,$66e
	dw $20e,$0,$0,$0
	dw $8268,$66e,$1110
	dw $208,$0
	dw $20f,$15a,$568,$9a2,$66e
	dw $20f,$0,$0,$0,$0
	dw $8261,$15a,$f10
	dw $200
	dw $227,$2b4,$66e,$568
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $247,$15a,$819,$66e
	dw $207,$0,$0,$0
	dw $8201,$15a,$d10
	dw $200
	dw $267,$2b4,$66e,$819
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $227,$134,$568,$611
	dw $207,$0,$0,$0
	dw $8205,$134,$611,$d10
	dw $204,$0
	dw $22f,$268,$66e,$568,$611
	dw $20e,$0,$0,$0
	dw $8208,$611,$d10
	dw $208,$0
	dw $247,$134,$ad0,$66e
	dw $207,$0,$0,$0
	dw $8201,$134,$b10
	dw $200
	dw $26f,$268,$9a2,$ad0,$611
	dw $20e,$0,$0,$0
	dw $8268,$611,$d10
	dw $208,$0
	dw $20f,$134,$568,$9a2,$611
	dw $20f,$0,$0,$0,$0
	dw $8241,$134,$b10
	dw $200
	dw $227,$268,$66e,$568
	dw $206,$0,$0
	dw $8200,$b10
	dw $200
	dw $247,$134,$819,$66e
	dw $207,$0,$0,$0
	dw $8201,$134,$910
	dw $200
	dw $247,$268,$66e,$819
	dw $206,$0,$0
	dw $8240,$b10
	dw $200
	dw $227,$e6,$568,$9a2
	dw $207,$0,$0,$0
	dw $8205,$e6,$9a2,$910
	dw $204,$0
	dw $26f,$1cd,$66e,$568,$611
	dw $20e,$0,$0,$0
	dw $8208,$611,$910
	dw $208,$0
	dw $247,$e6,$ad0,$66e
	dw $207,$0,$0,$0
	dw $8201,$e6,$710
	dw $200
	dw $26f,$1cd,$9a2,$ad0,$611
	dw $20e,$0,$0,$0
	dw $8268,$611,$910
	dw $208,$0
	dw $20f,$e6,$568,$9a2,$611
	dw $20f,$0,$0,$0,$0
	dw $8261,$e6,$710
	dw $200
	dw $227,$1cd,$66e,$568
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $247,$e6,$819,$66e
	dw $207,$0,$0,$0
	dw $8201,$e6,$510
	dw $200
	dw $267,$1cd,$66e,$819
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $227,$e6,$568,$ad0
	dw $207,$0,$0,$0
	dw $8205,$e6,$ad0,$510
	dw $204,$0
	dw $22f,$1cd,$66e,$568,$66e
	dw $20e,$0,$0,$0
	dw $8208,$66e,$510
	dw $208,$0
	dw $247,$e6,$ad0,$66e
	dw $207,$0,$0,$0
	dw $8201,$e6,$310
	dw $200
	dw $26f,$1cd,$9a2,$ad0,$66e
	dw $20e,$0,$0,$0
	dw $8248,$66e,$510
	dw $208,$0
	dw $22f,$e6,$568,$9a2,$66e
	dw $20f,$0,$0,$0,$0
	dw $8241,$e6,$310
	dw $200
	dw $227,$1cd,$66e,$568
	dw $206,$0,$0
	dw $8200,$310
	dw $200
	dw $247,$e6,$819,$66e
	dw $207,$0,$0,$0
	dw $8221,$e6,$510
	dw $200
	dw $247,$1cd,$66e,$819
	dw $206,$0,$0
	dw $8240,$310
	dw $200
	dw $227,$15a,$568,$66e
	dw $207,$0,$0,$0
	dw $8205,$15a,$66e,$310
	dw $204,$0
	dw $26f,$2b4,$66e,$568,$66e
	dw $20e,$0,$0,$0
	dw $8208,$66e,$310
	dw $208,$0
	dw $247,$15a,$ad0,$66e
	dw $207,$0,$0,$0
	dw $8201,$15a,$510
	dw $200
	dw $26f,$2b4,$9a2,$ad0,$66e
	dw $20e,$0,$0,$0
	dw $8268,$66e,$310
	dw $208,$0
	dw $20f,$15a,$568,$9a2,$66e
	dw $20f,$0,$0,$0,$0
	dw $8261,$15a,$510
	dw $200
	dw $227,$2b4,$66e,$568
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $247,$15a,$819,$66e
	dw $207,$0,$0,$0
	dw $8201,$15a,$710
	dw $200
	dw $267,$2b4,$66e,$819
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $227,$19b,$568,$611
	dw $207,$0,$0,$0
	dw $8205,$19b,$611,$710
	dw $204,$0
	dw $22f,$337,$66e,$568,$611
	dw $20e,$0,$0,$0
	dw $8208,$611,$710
	dw $208,$0
	dw $247,$19b,$ad0,$66e
	dw $207,$0,$0,$0
	dw $8201,$19b,$910
	dw $200
	dw $26f,$337,$9a2,$ad0,$611
	dw $20e,$0,$0,$0
	dw $8268,$611,$710
	dw $208,$0
	dw $20f,$19b,$568,$9a2,$611
	dw $20f,$0,$0,$0,$0
	dw $8241,$19b,$910
	dw $200
	dw $227,$337,$66e,$568
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $247,$19b,$819,$66e
	dw $207,$0,$0,$0
	dw $8201,$19b,$b10
	dw $200
	dw $247,$337,$66e,$819
	dw $206,$0,$0
	dw $8240,$910
	dw $200
	dw $227,$134,$568,$9a2
	dw $207,$0,$0,$0
	dw $8205,$134,$9a2,$b10
	dw $204,$0
	dw $26f,$268,$66e,$568,$611
	dw $20e,$0,$0,$0
	dw $8208,$611,$b10
	dw $208,$0
	dw $247,$134,$ad0,$66e
	dw $207,$0,$0,$0
	dw $8201,$134,$d10
	dw $200
	dw $26f,$268,$9a2,$ad0,$611
	dw $20e,$0,$0,$0
	dw $8268,$611,$b10
	dw $208,$0
	dw $20f,$134,$568,$9a2,$611
	dw $20f,$0,$0,$0,$0
	dw $8261,$134,$d10
	dw $200
	dw $227,$268,$66e,$568
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $247,$134,$819,$66e
	dw $207,$0,$0,$0
	dw $8201,$134,$f10
	dw $200
	dw $267,$268,$66e,$819
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $227,$134,$568,$ad0
	dw $207,$0,$0,$0
	dw $8205,$134,$ad0,$f10
	dw $204,$0
	dw $22f,$268,$66e,$568,$66e
	dw $20e,$0,$0,$0
	dw $8208,$66e,$f10
	dw $208,$0
	dw $247,$134,$ad0,$66e
	dw $207,$0,$0,$0
	dw $8201,$134,$1110
	dw $200
	dw $26f,$268,$9a2,$ad0,$66e
	dw $20e,$0,$0,$0
	dw $8248,$66e,$f10
	dw $208,$0
	dw $22f,$134,$568,$9a2,$66e
	dw $20f,$0,$0,$0,$0
	dw $8241,$134,$1110
	dw $200
	dw $227,$268,$66e,$568
	dw $207,$0,$0,$0
	dw $8201,$268,$1110
	dw $201,$0
	dw $247,$268,$819,$66e
	dw $207,$0,$0,$0
	dw $8221,$268,$f10
	dw $201,$0
	dw $247,$268,$66e,$819
	dw $207,$0,$0,$0
	dw $8241,$268,$1110
	dw $201,$0
	dw $227,$15a,$568,$66e
	dw $203,$0,$0
	dw $8205,$15a,$0,$1110
	dw $200
	dw $267,$2b4,$66e,$568
	dw $206,$0,$0
	dw $8208,$66e,$1110
	dw $200
	dw $24f,$15a,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$15a,$f10
	dw $200
	dw $26f,$2b4,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8268,$0,$1110
	dw $200
	dw $207,$15a,$568,$9a2
	dw $207,$0,$0,$0
	dw $8269,$15a,$cdc,$f10
	dw $200
	dw $22f,$2b4,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $24f,$15a,$819,$66e,$c23
	dw $207,$0,$0,$0
	dw $8209,$15a,$0,$d10
	dw $200
	dw $267,$2b4,$66e,$819
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $227,$134,$568,$9a2
	dw $203,$0,$0
	dw $8205,$134,$0,$d10
	dw $200
	dw $227,$268,$66e,$568
	dw $206,$0,$0
	dw $8208,$9a2,$d10
	dw $200
	dw $24f,$134,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$134,$b10
	dw $200
	dw $26f,$268,$9a2,$ad0,$e6e
	dw $206,$0,$0
	dw $8268,$0,$d10
	dw $200
	dw $207,$134,$568,$9a2
	dw $207,$0,$0,$0
	dw $8249,$134,$e6e,$b10
	dw $200
	dw $22f,$268,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$b10
	dw $200
	dw $24f,$134,$819,$66e,$737
	dw $207,$0,$0,$0
	dw $8209,$134,$0,$910
	dw $200
	dw $247,$268,$66e,$819
	dw $206,$0,$0
	dw $8240,$b10
	dw $200
	dw $227,$e6,$568,$611
	dw $203,$0,$0
	dw $8205,$e6,$0,$910
	dw $200
	dw $267,$1cd,$66e,$568
	dw $206,$0,$0
	dw $8208,$611,$910
	dw $200
	dw $24f,$e6,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$e6,$710
	dw $200
	dw $26f,$1cd,$9a2,$ad0,$c23
	dw $206,$0,$0
	dw $8268,$0,$910
	dw $200
	dw $207,$e6,$568,$9a2
	dw $207,$0,$0,$0
	dw $8269,$e6,$c23,$710
	dw $200
	dw $22f,$1cd,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $24f,$e6,$819,$66e,$9a2
	dw $207,$0,$0,$0
	dw $8209,$e6,$0,$510
	dw $200
	dw $267,$1cd,$66e,$819
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $227,$e6,$568,$ad0
	dw $203,$0,$0
	dw $8205,$e6,$0,$510
	dw $200
	dw $227,$1cd,$66e,$568
	dw $206,$0,$0
	dw $8208,$ad0,$510
	dw $200
	dw $24f,$e6,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$e6,$310
	dw $200
	dw $26f,$1cd,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8248,$0,$510
	dw $200
	dw $227,$e6,$568,$9a2
	dw $207,$0,$0,$0
	dw $8249,$e6,$cdc,$310
	dw $200
	dw $22f,$1cd,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$310
	dw $200
	dw $24f,$e6,$819,$66e,$737
	dw $207,$0,$0,$0
	dw $8229,$e6,$0,$510
	dw $200
	dw $247,$1cd,$66e,$819
	dw $206,$0,$0
	dw $8240,$310
	dw $200
	dw $227,$15a,$568,$66e
	dw $203,$0,$0
	dw $8205,$15a,$0,$310
	dw $200
	dw $267,$2b4,$66e,$568
	dw $206,$0,$0
	dw $8208,$66e,$310
	dw $200
	dw $24f,$15a,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$15a,$510
	dw $200
	dw $26f,$2b4,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8268,$0,$310
	dw $200
	dw $207,$15a,$568,$9a2
	dw $207,$0,$0,$0
	dw $8269,$15a,$cdc,$510
	dw $200
	dw $22f,$2b4,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $24f,$15a,$819,$66e,$c23
	dw $207,$0,$0,$0
	dw $8209,$15a,$0,$710
	dw $200
	dw $267,$2b4,$66e,$819
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $227,$19b,$568,$9a2
	dw $203,$0,$0
	dw $8205,$19b,$0,$710
	dw $200
	dw $227,$337,$66e,$568
	dw $206,$0,$0
	dw $8208,$9a2,$710
	dw $200
	dw $24f,$19b,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$19b,$910
	dw $200
	dw $26f,$337,$9a2,$ad0,$e6e
	dw $206,$0,$0
	dw $8268,$0,$710
	dw $200
	dw $207,$19b,$568,$9a2
	dw $207,$0,$0,$0
	dw $8249,$19b,$e6e,$910
	dw $200
	dw $22f,$337,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $24f,$19b,$819,$66e,$737
	dw $207,$0,$0,$0
	dw $8209,$19b,$0,$b10
	dw $200
	dw $247,$337,$66e,$819
	dw $206,$0,$0
	dw $8240,$910
	dw $200
	dw $227,$134,$568,$611
	dw $203,$0,$0
	dw $8205,$134,$0,$b10
	dw $200
	dw $267,$268,$66e,$568
	dw $206,$0,$0
	dw $8208,$611,$b10
	dw $200
	dw $24f,$134,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$134,$d10
	dw $200
	dw $26f,$268,$9a2,$ad0,$c23
	dw $206,$0,$0
	dw $8268,$0,$b10
	dw $200
	dw $207,$134,$568,$9a2
	dw $207,$0,$0,$0
	dw $8269,$134,$c23,$d10
	dw $200
	dw $22f,$268,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $24f,$134,$819,$66e,$9a2
	dw $207,$0,$0,$0
	dw $8209,$134,$0,$f10
	dw $200
	dw $247,$268,$66e,$819
	dw $206,$0,$0
	dw $8240,$d10
	dw $200
	dw $227,$134,$568,$ad0
	dw $203,$0,$0
	dw $8245,$134,$0,$f10
	dw $200
	dw $227,$268,$66e,$568
	dw $206,$0,$0
	dw $8208,$ad0,$f10
	dw $200
	dw $24f,$134,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8241,$134,$1120
	dw $200
	dw $24f,$268,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8248,$0,$f20
	dw $201,$0
	dw $227,$268,$568,$9a2
	dw $206,$0,$0
	dw $8209,$0,$cdc,$1140
	dw $200
	dw $22f,$268,$66e,$568,$0
	dw $206,$0,$0
	dw $8201,$0,$1140
	dw $200
	dw $22f,$268,$819,$66e,$737
	dw $206,$0,$0
	dw $8209,$0,$0,$f80
	dw $200
	dw $227,$268,$66e,$819
	dw $226,$0,$0
	dw $8221,$0,$1180
	dw $220
	dw $227,$15a,$737,$819
	dw $207,$0,$819,$0
	dw $201,$15a
	dw $201,$0
	dw $265,$2b4,$568
	dw $205,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $24f,$15a,$0,$66e,$737
	dw $20d,$0,$0,$819
	dw $201,$15a
	dw $201,$0
	dw $267,$2b4,$819,$568
	dw $205,$0,$0
	dw $263,$2b4,$0
	dw $201,$0
	dw $20f,$15a,$737,$819,$0
	dw $205,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $22f,$2b4,$0,$568,$819
	dw $205,$0,$0
	dw $269,$2b4,$0
	dw $201,$0
	dw $24f,$15a,$611,$66e,$737
	dw $205,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $26f,$2b4,$66e,$568,$0
	dw $205,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $22f,$134,$0,$819,$611
	dw $205,$0,$0
	dw $201,$134
	dw $201,$0
	dw $26d,$268,$568,$66e
	dw $205,$0,$0
	dw $261,$268
	dw $201,$0
	dw $24f,$134,$819,$66e,$0
	dw $205,$0,$0
	dw $203,$134,$0
	dw $201,$0
	dw $267,$268,$737,$568
	dw $205,$0,$0
	dw $261,$268
	dw $201,$0
	dw $20f,$134,$0,$819,$819
	dw $205,$0,$0
	dw $209,$134,$0
	dw $201,$0
	dw $22f,$268,$611,$568,$737
	dw $205,$0,$0
	dw $261,$268
	dw $201,$0
	dw $24d,$134,$66e,$0
	dw $205,$0,$0
	dw $201,$134
	dw $201,$0
	dw $26f,$268,$66e,$568,$611
	dw $205,$0,$0
	dw $261,$268
	dw $201,$0
	dw $225,$1cd,$819
	dw $205,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $26d,$39b,$568,$66e
	dw $205,$0,$0
	dw $261,$39b
	dw $201,$0
	dw $245,$1cd,$66e
	dw $205,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $267,$39b,$737,$568
	dw $205,$0,$0
	dw $261,$39b
	dw $201,$0
	dw $205,$1cd,$819
	dw $205,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $22f,$39b,$737,$568,$737
	dw $207,$0,$0,$0
	dw $263,$39b,$72f
	dw $203,$0,$0
	dw $247,$1cd,$727,$66e
	dw $207,$0,$0,$0
	dw $203,$1cd,$71f
	dw $203,$0,$0
	dw $26f,$39b,$717,$568,$737
	dw $20f,$0,$0,$0,$0
	dw $26b,$39b,$70f,$72f
	dw $20b,$0,$0,$0
	dw $22d,$1cd,$819,$727
	dw $20d,$0,$0,$0
	dw $209,$1cd,$71f
	dw $209,$0,$0
	dw $26d,$39b,$568,$717
	dw $20d,$0,$0,$0
	dw $269,$39b,$70f
	dw $209,$0,$0
	dw $247,$1cd,$70f,$66e
	dw $207,$0,$0,$0
	dw $203,$1cd,$717
	dw $203,$0,$0
	dw $267,$39b,$71f,$568
	dw $207,$0,$0,$0
	dw $263,$39b,$727
	dw $203,$0,$0
	dw $20f,$1cd,$72f,$819,$70f
	dw $20f,$0,$0,$0,$0
	dw $209,$1cd,$717
	dw $209,$0,$0
	dw $22f,$39b,$e6e,$568,$71f
	dw $20f,$0,$0,$0,$0
	dw $26b,$39b,$e66,$727
	dw $20b,$0,$0,$0
	dw $24f,$1cd,$e5e,$66e,$72f
	dw $20f,$0,$0,$0,$0
	dw $203,$1cd,$e56
	dw $203,$0,$0
	dw $26f,$39b,$e4e,$568,$e6e
	dw $20f,$0,$0,$0,$0
	dw $26b,$39b,$e46,$e66
	dw $20b,$0,$0,$0
	dw $22d,$15a,$819,$e5e
	dw $20d,$0,$0,$0
	dw $209,$15a,$e56
	dw $209,$0,$0
	dw $26d,$2b4,$568,$e4e
	dw $20d,$0,$0,$0
	dw $269,$2b4,$e46
	dw $209,$0,$0
	dw $245,$15a,$66e
	dw $205,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $267,$2b4,$737,$568
	dw $205,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $207,$15a,$819,$819
	dw $205,$0,$0
	dw $203,$15a,$0
	dw $201,$0
	dw $22f,$2b4,$9a2,$568,$737
	dw $205,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $24f,$15a,$0,$66e,$819
	dw $205,$0,$0
	dw $209,$15a,$0
	dw $201,$0
	dw $26f,$2b4,$cdc,$568,$9a2
	dw $205,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $22d,$19b,$819,$0
	dw $205,$0,$0
	dw $201,$19b
	dw $201,$0
	dw $26f,$337,$0,$568,$cdc
	dw $205,$0,$0
	dw $261,$337
	dw $201,$0
	dw $245,$19b,$66e
	dw $205,$0,$0
	dw $201,$19b
	dw $201,$0
	dw $26f,$337,$c23,$568,$0
	dw $205,$0,$0
	dw $261,$337
	dw $201,$0
	dw $207,$19b,$9a2,$819
	dw $205,$0,$0
	dw $201,$19b
	dw $201,$0
	dw $22f,$337,$0,$568,$c23
	dw $205,$0,$0
	dw $261,$337
	dw $201,$0
	dw $24f,$19b,$737,$66e,$9a2
	dw $205,$0,$0
	dw $201,$19b
	dw $201,$0
	dw $26f,$337,$0,$568,$0
	dw $205,$0,$0
	dw $261,$337
	dw $201,$0
	dw $22f,$134,$611,$819,$737
	dw $205,$0,$0
	dw $201,$134
	dw $201,$0
	dw $26d,$268,$568,$0
	dw $205,$0,$0
	dw $261,$268
	dw $201,$0
	dw $24f,$134,$611,$66e,$611
	dw $207,$0,$0,$0
	dw $203,$134,$611
	dw $203,$0,$0
	dw $267,$268,$611,$568
	dw $207,$0,$0,$0
	dw $263,$268,$611
	dw $203,$0,$0
	dw $20f,$134,$611,$819,$609
	dw $20d,$0,$0,$0
	dw $209,$134,$601
	dw $209,$0,$0
	dw $22d,$268,$568,$5f9
	dw $20d,$0,$0,$0
	dw $269,$268,$5f1
	dw $209,$0,$0
	dw $24f,$134,$66e,$66e,$5e9
	dw $20f,$0,$0,$0,$0
	dw $203,$134,$66e
	dw $203,$0,$0
	dw $26f,$268,$66e,$568,$568
	dw $20f,$0,$0,$0,$0
	dw $263,$268,$66e
	dw $203,$0,$0
	dw $22f,$134,$66e,$819,$666
	dw $20d,$0,$0,$0
	dw $209,$134,$65e
	dw $209,$0,$0
	dw $26d,$268,$568,$656
	dw $20d,$0,$0,$0
	dw $269,$268,$64e
	dw $209,$0,$0
	dw $24f,$134,$737,$66e,$646
	dw $20f,$0,$0,$0,$0
	dw $203,$134,$737
	dw $203,$0,$0
	dw $26f,$268,$737,$568,$568
	dw $20f,$0,$0,$0,$0
	dw $263,$268,$737
	dw $203,$0,$0
	dw $22f,$4d1,$308,$819,$72f
	dw $20f,$0,$0,$0,$0
	dw $24b,$4d1,$308,$727
	dw $20b,$0,$0,$0
	dw $22f,$268,$308,$568,$71f
	dw $20f,$0,$0,$0,$0
	dw $24b,$268,$308,$717
	dw $20b,$0,$0,$0
	dw $24f,$4d1,$308,$66e,$70f
	dw $20f,$0,$0,$0,$0
	dw $223,$4d1,$308
	dw $203,$0,$0
	dw $24f,$268,$308,$568,$568
	dw $20f,$0,$0,$0,$0
	dw $243,$268,$308
	dw $203,$0,$0
	dw $227,$15a,$568,$819
	dw $205,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $265,$2b4,$568
	dw $205,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $24d,$15a,$66e,$568
	dw $205,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $8267,$2b4,$611,$568,$f10
	dw $205,$0,$0
	dw $8261,$2b4,$f20
	dw $201,$0
	dw $207,$15a,$66e,$819
	dw $205,$0,$0
	dw $8201,$15a,$f20
	dw $201,$0
	dw $822f,$2b4,$0,$568,$611,$f10
	dw $205,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $24f,$15a,$611,$66e,$66e
	dw $205,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $26f,$2b4,$66e,$568,$568
	dw $20d,$0,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $22d,$134,$819,$611
	dw $205,$0,$0
	dw $201,$134
	dw $201,$0
	dw $26f,$268,$0,$568,$66e
	dw $205,$0,$0
	dw $261,$268
	dw $201,$0
	dw $245,$134,$66e
	dw $205,$0,$0
	dw $201,$134
	dw $201,$0
	dw $826f,$268,$4d1,$568,$568,$d10
	dw $20d,$0,$0,$0
	dw $8263,$268,$0,$d20
	dw $201,$0
	dw $20f,$134,$611,$819,$66e
	dw $20d,$0,$0,$0
	dw $8203,$134,$0,$d20
	dw $201,$0
	dw $822f,$268,$737,$568,$4d1,$d10
	dw $205,$0,$0
	dw $26b,$268,$0,$0
	dw $201,$0
	dw $24d,$134,$66e,$611
	dw $205,$0,$0
	dw $209,$134,$0
	dw $201,$0
	dw $26f,$268,$737,$568,$737
	dw $207,$0,$819,$0
	dw $269,$268,$0
	dw $201,$0
	dw $22d,$1cd,$819,$66e
	dw $20d,$0,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $26d,$39b,$568,$737
	dw $20d,$0,$0,$819
	dw $261,$39b
	dw $201,$0
	dw $247,$1cd,$66e,$66e
	dw $205,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $826d,$39b,$568,$568,$b10
	dw $20d,$0,$0,$0
	dw $8261,$39b,$b20
	dw $201,$0
	dw $20f,$1cd,$66e,$819,$66e
	dw $207,$0,$0,$0
	dw $8203,$1cd,$66e,$b20
	dw $203,$0,$0
	dw $8227,$39b,$66e,$568,$b10
	dw $207,$0,$0,$0
	dw $263,$39b,$66e
	dw $203,$0,$0
	dw $24f,$1cd,$66e,$66e,$666
	dw $20f,$0,$0,$0,$0
	dw $209,$1cd,$65e
	dw $209,$0,$0
	dw $26d,$39b,$568,$656
	dw $20d,$0,$0,$0
	dw $269,$39b,$64e
	dw $209,$0,$0
	dw $22f,$1cd,$568,$819,$646
	dw $20f,$0,$0,$0,$0
	dw $203,$1cd,$568
	dw $203,$0,$0
	dw $26f,$39b,$568,$568,$568
	dw $20f,$0,$0,$0,$0
	dw $263,$39b,$ad0
	dw $203,$0,$0
	dw $24f,$1cd,$ad0,$66e,$560
	dw $20f,$0,$0,$0,$0
	dw $209,$1cd,$558
	dw $209,$0,$0
	dw $826f,$39b,$611,$568,$550,$910
	dw $20f,$0,$0,$0,$0
	dw $826b,$39b,$611,$ab0,$920
	dw $20b,$0,$0,$0
	dw $20f,$1cd,$611,$819,$aa8
	dw $20f,$0,$0,$0,$0
	dw $8203,$1cd,$c23,$920
	dw $203,$0,$0
	dw $822f,$39b,$c23,$568,$609,$910
	dw $20f,$0,$0,$0,$0
	dw $269,$39b,$601
	dw $209,$0,$0
	dw $24f,$1cd,$737,$66e,$5f9
	dw $20f,$0,$0,$0,$0
	dw $20b,$1cd,$737,$c03
	dw $20b,$0,$0,$0
	dw $26f,$39b,$737,$568,$bfb
	dw $20f,$0,$0,$0,$0
	dw $263,$39b,$e6e
	dw $203,$0,$0
	dw $22f,$15a,$e6e,$819,$72f
	dw $20f,$0,$0,$0,$0
	dw $209,$15a,$727
	dw $209,$0,$0
	dw $26d,$2b4,$568,$71f
	dw $20d,$0,$0,$0
	dw $269,$2b4,$e4e
	dw $209,$0,$0
	dw $24d,$15a,$66e,$e46
	dw $20d,$0,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $826f,$2b4,$737,$568,$568,$710
	dw $20d,$0,$0,$0
	dw $8261,$2b4,$720
	dw $201,$0
	dw $20f,$15a,$66e,$819,$66e
	dw $20d,$0,$0,$0
	dw $8201,$15a,$720
	dw $201,$0
	dw $822f,$2b4,$0,$568,$737,$710
	dw $205,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $24f,$15a,$40c,$66e,$66e
	dw $205,$0,$0
	dw $201,$15a
	dw $201,$0
	dw $26f,$2b4,$611,$568,$568
	dw $20d,$0,$0,$0
	dw $261,$2b4
	dw $201,$0
	dw $22d,$19b,$819,$40c
	dw $205,$0,$0
	dw $201,$19b
	dw $201,$0
	dw $26d,$337,$568,$611
	dw $205,$0,$0
	dw $261,$337
	dw $201,$0
	dw $247,$19b,$0,$66e
	dw $205,$0,$0
	dw $201,$19b
	dw $201,$0
	dw $8267,$337,$337,$568,$510
	dw $205,$0,$0
	dw $8261,$337,$520
	dw $201,$0
	dw $20f,$19b,$39b,$819,$66e
	dw $20d,$0,$0,$0
	dw $8201,$19b,$520
	dw $201,$0
	dw $822f,$337,$0,$568,$337,$510
	dw $205,$0,$0
	dw $261,$337
	dw $201,$0
	dw $24f,$19b,$4d1,$66e,$39b
	dw $205,$0,$0
	dw $201,$19b
	dw $201,$0
	dw $26d,$337,$568,$568
	dw $20d,$0,$0,$0
	dw $261,$337
	dw $201,$0
	dw $22f,$1cd,$39b,$819,$4d1
	dw $205,$0,$0
	dw $201,$1cd
	dw $201,$0
	dw $265,$39b,$568
	dw $205,$0,$0
	dw $261,$39b
	dw $201,$0
	dw $24f,$1cd,$39b,$66e,$393
	dw $207,$0,$0,$0
	dw $203,$1cd,$39b
	dw $203,$0,$0
	dw $8267,$39b,$39b,$568,$310
	dw $207,$0,$0,$0
	dw $8263,$39b,$39b,$320
	dw $203,$0,$0
	dw $20f,$1cd,$737,$819,$393
	dw $20d,$0,$0,$0
	dw $8209,$1cd,$38b,$320
	dw $209,$0,$0
	dw $822d,$39b,$568,$383,$310
	dw $20d,$0,$0,$0
	dw $269,$39b,$37b
	dw $209,$0,$0
	dw $24f,$1cd,$737,$66e,$70f
	dw $20f,$0,$0,$0,$0
	dw $203,$1cd,$737
	dw $203,$0,$0
	dw $26f,$39b,$737,$568,$568
	dw $20f,$0,$0,$0,$0
	dw $263,$39b,$737
	dw $203,$0,$0
	dw $22f,$39b,$568,$819,$72f
	dw $20d,$0,$0,$0
	dw $209,$39b,$727
	dw $209,$0,$0
	dw $26d,$39b,$568,$71f
	dw $20d,$0,$0,$0
	dw $269,$39b,$717
	dw $209,$0,$0
	dw $20f,$39b,$568,$66e,$558
	dw $207,$0,$0,$0
	dw $203,$39b,$568
	dw $203,$0,$0
	dw $267,$39b,$568,$568
	dw $207,$0,$0,$0
	dw $263,$39b,$568
	dw $203,$0,$0
	dw $20f,$e6,$568,$819,$1c5
	dw $206,$0,$0
	dw $200
	dw $200
	dw $224,$568
	dw $204,$0
	dw $220
	dw $200
	dw $224,$66e
	dw $204,$0
	dw $220
	dw $200
	dw $224,$568
	dw $204,$0
	dw $220
	dw $200
	dw $26f,$15a,$568,$66e,$0
	dw $203,$0,$0
	dw $205,$15a,$0
	dw $200
	dw $207,$2b4,$66e,$568
	dw $206,$0,$0
	dw $208,$66e
	dw $200
	dw $20f,$15a,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $201,$15a
	dw $200
	dw $20f,$2b4,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $208,$0
	dw $200
	dw $207,$15a,$568,$9a2
	dw $207,$0,$0,$0
	dw $209,$15a,$cdc
	dw $200
	dw $20f,$2b4,$66e,$568,$0
	dw $206,$0,$0
	dw $200
	dw $200
	dw $20f,$15a,$819,$66e,$c23
	dw $207,$0,$0,$0
	dw $209,$15a,$0
	dw $200
	dw $207,$2b4,$66e,$819
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$134,$568,$9a2
	dw $203,$0,$0
	dw $205,$134,$0
	dw $200
	dw $207,$268,$66e,$568
	dw $206,$0,$0
	dw $208,$9a2
	dw $200
	dw $20f,$134,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $201,$134
	dw $200
	dw $20f,$268,$9a2,$ad0,$e6e
	dw $206,$0,$0
	dw $208,$0
	dw $200
	dw $207,$134,$568,$9a2
	dw $207,$0,$0,$0
	dw $209,$134,$e6e
	dw $200
	dw $20f,$268,$66e,$568,$0
	dw $206,$0,$0
	dw $200
	dw $200
	dw $20f,$134,$819,$66e,$737
	dw $207,$0,$0,$0
	dw $209,$134,$0
	dw $200
	dw $207,$268,$66e,$819
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$e6,$568,$611
	dw $203,$0,$0
	dw $205,$e6,$0
	dw $200
	dw $207,$1cd,$66e,$568
	dw $206,$0,$0
	dw $208,$611
	dw $200
	dw $20f,$e6,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $201,$e6
	dw $200
	dw $20f,$1cd,$9a2,$ad0,$c23
	dw $206,$0,$0
	dw $208,$0
	dw $200
	dw $207,$e6,$568,$9a2
	dw $207,$0,$0,$0
	dw $209,$e6,$c23
	dw $200
	dw $20f,$1cd,$66e,$568,$0
	dw $206,$0,$0
	dw $200
	dw $200
	dw $20f,$e6,$819,$66e,$9a2
	dw $207,$0,$0,$0
	dw $209,$e6,$0
	dw $200
	dw $207,$1cd,$66e,$819
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$e6,$568,$ad0
	dw $203,$0,$0
	dw $205,$e6,$0
	dw $200
	dw $207,$1cd,$66e,$568
	dw $206,$0,$0
	dw $208,$ad0
	dw $200
	dw $20f,$e6,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $201,$e6
	dw $200
	dw $20f,$1cd,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $208,$0
	dw $200
	dw $207,$e6,$568,$9a2
	dw $207,$0,$0,$0
	dw $209,$e6,$cdc
	dw $200
	dw $20f,$1cd,$66e,$568,$0
	dw $206,$0,$0
	dw $200
	dw $200
	dw $20f,$e6,$819,$66e,$737
	dw $207,$0,$0,$0
	dw $209,$e6,$0
	dw $200
	dw $207,$1cd,$66e,$819
	dw $206,$0,$0
	dw $200
	dw $200
	dw $207,$15a,$568,$66e
	dw $203,$0,$0
	dw $8205,$15a,$0,$310
	dw $200
	dw $207,$2b4,$66e,$568
	dw $206,$0,$0
	dw $8208,$66e,$310
	dw $200
	dw $20f,$15a,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$15a,$510
	dw $200
	dw $20f,$2b4,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8208,$0,$310
	dw $200
	dw $207,$15a,$568,$9a2
	dw $207,$0,$0,$0
	dw $8209,$15a,$cdc,$510
	dw $200
	dw $20f,$2b4,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $20f,$15a,$819,$66e,$c23
	dw $207,$0,$0,$0
	dw $8209,$15a,$0,$710
	dw $200
	dw $207,$2b4,$66e,$819
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $207,$19b,$568,$9a2
	dw $203,$0,$0
	dw $8205,$19b,$0,$710
	dw $200
	dw $207,$337,$66e,$568
	dw $206,$0,$0
	dw $8208,$9a2,$710
	dw $200
	dw $20f,$19b,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$19b,$910
	dw $200
	dw $20f,$337,$9a2,$ad0,$e6e
	dw $206,$0,$0
	dw $8208,$0,$710
	dw $200
	dw $207,$19b,$568,$9a2
	dw $207,$0,$0,$0
	dw $8209,$19b,$e6e,$910
	dw $200
	dw $20f,$337,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $20f,$19b,$819,$66e,$737
	dw $207,$0,$0,$0
	dw $8209,$19b,$0,$b10
	dw $200
	dw $207,$337,$66e,$819
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $207,$134,$568,$611
	dw $203,$0,$0
	dw $8205,$134,$0,$b10
	dw $200
	dw $207,$268,$66e,$568
	dw $206,$0,$0
	dw $8208,$611,$b10
	dw $200
	dw $20f,$134,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$134,$d10
	dw $200
	dw $20f,$268,$9a2,$ad0,$c23
	dw $206,$0,$0
	dw $8208,$0,$b10
	dw $200
	dw $207,$134,$568,$9a2
	dw $207,$0,$0,$0
	dw $8209,$134,$c23,$d10
	dw $200
	dw $20f,$268,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $20f,$134,$819,$66e,$9a2
	dw $207,$0,$0,$0
	dw $8209,$134,$0,$f10
	dw $200
	dw $207,$268,$66e,$819
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $227,$134,$568,$ad0
	dw $203,$0,$0
	dw $8205,$134,$0,$f10
	dw $200
	dw $227,$268,$66e,$568
	dw $206,$0,$0
	dw $8208,$ad0,$f10
	dw $200
	dw $22f,$134,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$134,$1120
	dw $200
	dw $22f,$268,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8208,$0,$f20
	dw $201,$0
	dw $247,$268,$568,$9a2
	dw $206,$0,$0
	dw $8249,$0,$cdc,$1140
	dw $200
	dw $24f,$268,$66e,$568,$0
	dw $206,$0,$0
	dw $8241,$0,$1140
	dw $200
	dw $24f,$268,$819,$66e,$737
	dw $246,$0,$0
	dw $8249,$0,$0,$f80
	dw $240
	dw $247,$268,$66e,$819
	dw $246,$0,$0
	dw $8241,$0,$1180
	dw $240
	dw $227,$15a,$568,$66e
	dw $203,$0,$0
	dw $8205,$15a,$0,$1110
	dw $200
	dw $267,$2b4,$66e,$568
	dw $206,$0,$0
	dw $8208,$66e,$1110
	dw $200
	dw $24f,$15a,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$15a,$f10
	dw $200
	dw $26f,$2b4,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8268,$0,$1110
	dw $200
	dw $207,$15a,$568,$9a2
	dw $207,$0,$0,$0
	dw $8269,$15a,$cdc,$f10
	dw $200
	dw $22f,$2b4,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $24f,$15a,$819,$66e,$c23
	dw $207,$0,$0,$0
	dw $8209,$15a,$0,$d10
	dw $200
	dw $267,$2b4,$66e,$819
	dw $206,$0,$0
	dw $8200,$f10
	dw $200
	dw $227,$134,$568,$9a2
	dw $203,$0,$0
	dw $8205,$134,$0,$d10
	dw $200
	dw $227,$268,$66e,$568
	dw $206,$0,$0
	dw $8208,$9a2,$d10
	dw $200
	dw $24f,$134,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$134,$b10
	dw $200
	dw $26f,$268,$9a2,$ad0,$e6e
	dw $206,$0,$0
	dw $8268,$0,$d10
	dw $200
	dw $207,$134,$568,$9a2
	dw $207,$0,$0,$0
	dw $8249,$134,$e6e,$b10
	dw $200
	dw $22f,$268,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$b10
	dw $200
	dw $24f,$134,$819,$66e,$737
	dw $207,$0,$0,$0
	dw $8209,$134,$0,$910
	dw $200
	dw $247,$268,$66e,$819
	dw $206,$0,$0
	dw $8240,$b10
	dw $200
	dw $227,$e6,$568,$611
	dw $203,$0,$0
	dw $8205,$e6,$0,$910
	dw $200
	dw $267,$1cd,$66e,$568
	dw $206,$0,$0
	dw $8208,$611,$910
	dw $200
	dw $24f,$e6,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$e6,$710
	dw $200
	dw $26f,$1cd,$9a2,$ad0,$c23
	dw $206,$0,$0
	dw $8268,$0,$910
	dw $200
	dw $207,$e6,$568,$9a2
	dw $207,$0,$0,$0
	dw $8269,$e6,$c23,$710
	dw $200
	dw $22f,$1cd,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $24f,$e6,$819,$66e,$9a2
	dw $207,$0,$0,$0
	dw $8209,$e6,$0,$510
	dw $200
	dw $267,$1cd,$66e,$819
	dw $206,$0,$0
	dw $8200,$710
	dw $200
	dw $227,$e6,$568,$ad0
	dw $203,$0,$0
	dw $8205,$e6,$0,$510
	dw $200
	dw $227,$1cd,$66e,$568
	dw $206,$0,$0
	dw $8208,$ad0,$510
	dw $200
	dw $24f,$e6,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$e6,$310
	dw $200
	dw $26f,$1cd,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8248,$0,$510
	dw $200
	dw $227,$e6,$568,$9a2
	dw $207,$0,$0,$0
	dw $8249,$e6,$cdc,$310
	dw $200
	dw $22f,$1cd,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$310
	dw $200
	dw $24f,$e6,$819,$66e,$737
	dw $207,$0,$0,$0
	dw $8229,$e6,$0,$510
	dw $200
	dw $247,$1cd,$66e,$819
	dw $206,$0,$0
	dw $8240,$310
	dw $200
	dw $227,$15a,$568,$66e
	dw $203,$0,$0
	dw $8205,$15a,$0,$310
	dw $200
	dw $267,$2b4,$66e,$568
	dw $206,$0,$0
	dw $8208,$66e,$310
	dw $200
	dw $24f,$15a,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$15a,$510
	dw $200
	dw $26f,$2b4,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8268,$0,$310
	dw $200
	dw $207,$15a,$568,$9a2
	dw $207,$0,$0,$0
	dw $8269,$15a,$cdc,$510
	dw $200
	dw $22f,$2b4,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $24f,$15a,$819,$66e,$c23
	dw $207,$0,$0,$0
	dw $8209,$15a,$0,$710
	dw $200
	dw $267,$2b4,$66e,$819
	dw $206,$0,$0
	dw $8200,$510
	dw $200
	dw $227,$19b,$568,$9a2
	dw $203,$0,$0
	dw $8205,$19b,$0,$710
	dw $200
	dw $227,$337,$66e,$568
	dw $206,$0,$0
	dw $8208,$9a2,$710
	dw $200
	dw $24f,$19b,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$19b,$910
	dw $200
	dw $26f,$337,$9a2,$ad0,$e6e
	dw $206,$0,$0
	dw $8268,$0,$710
	dw $200
	dw $207,$19b,$568,$9a2
	dw $207,$0,$0,$0
	dw $8249,$19b,$e6e,$910
	dw $200
	dw $22f,$337,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$910
	dw $200
	dw $24f,$19b,$819,$66e,$737
	dw $207,$0,$0,$0
	dw $8209,$19b,$0,$b10
	dw $200
	dw $247,$337,$66e,$819
	dw $206,$0,$0
	dw $8240,$910
	dw $200
	dw $227,$134,$568,$611
	dw $203,$0,$0
	dw $8205,$134,$0,$b10
	dw $200
	dw $267,$268,$66e,$568
	dw $206,$0,$0
	dw $8208,$611,$b10
	dw $200
	dw $24f,$134,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8201,$134,$d10
	dw $200
	dw $26f,$268,$9a2,$ad0,$c23
	dw $206,$0,$0
	dw $8268,$0,$b10
	dw $200
	dw $207,$134,$568,$9a2
	dw $207,$0,$0,$0
	dw $8269,$134,$c23,$d10
	dw $200
	dw $22f,$268,$66e,$568,$0
	dw $206,$0,$0
	dw $8200,$d10
	dw $200
	dw $24f,$134,$819,$66e,$9a2
	dw $207,$0,$0,$0
	dw $8209,$134,$0,$f10
	dw $200
	dw $247,$268,$66e,$819
	dw $206,$0,$0
	dw $8240,$d10
	dw $200
	dw $227,$134,$568,$ad0
	dw $203,$0,$0
	dw $8245,$134,$0,$f10
	dw $200
	dw $227,$268,$66e,$568
	dw $206,$0,$0
	dw $8208,$ad0,$f10
	dw $200
	dw $24f,$134,$ad0,$66e,$0
	dw $207,$0,$0,$0
	dw $8241,$134,$1120
	dw $200
	dw $24f,$268,$9a2,$ad0,$cdc
	dw $206,$0,$0
	dw $8248,$0,$f20
	dw $201,$0
	dw $227,$268,$568,$9a2
	dw $206,$0,$0
	dw $8209,$0,$cdc,$1140
	dw $200
	dw $22f,$268,$66e,$568,$0
	dw $206,$0,$0
	dw $8201,$0,$1140
	dw $200
	dw $22f,$268,$819,$66e,$737
	dw $206,$0,$0
	dw $8209,$0,$0,$f80
	dw $200
	dw $227,$268,$66e,$819
	dw $226,$0,$0
	dw $8221,$0,$1180
	dw $220
	dw $24f,$2b4,$2ac,$15a,$152
	dw $201,$0
	dw $201,$2b4
	dw $201,$0
	dw $201,$2b4
	dw $200
	dw $200
	dw $200
	dw $20b,$0,$2b4,$15a
	dw $20a,$0,$0
	dw $20a,$2b4,$15a
	dw $20a,$0,$0
	dw $20a,$2b4,$15a
	dw $200
	dw $200
	dw $200
	dw $20a,$0,$15a
	dw $208,$0
	dw $208,$15a
	dw $208,$0
	dw $208,$15a
	dw $200
	dw $200
	dw $200
	dw $20c,$0,$15a
	dw $208,$0
	dw $208,$15a
	dw $208,$0
	dw $208,$15a
	dw $200
	dw $200
	dw $200
	dw $20c,$15a,$0
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $204,$0
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
	dw $200
.loop
	dw $7f1f,0,0,0,0,NOP_2
	dw 0
